pilas.interprete.VentanaInterprete

Package pilas :: Module interprete :: Class VentanaInterprete |
[hide private]
[frames] | no frames]

# Class VentanaInterprete

source code

    object --+
             |
            VentanaInterprete

Instance Methods | [hide private]
setupUi(self, main) | source code
_insertar_ventana_principal_de_pilas(self) | source code
_insertar_consola_interactiva(self, scope) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`